@@ -12,15 +12,23 @@ module MerbExceptions
           request = self.request
 
           details = {}
-          details['exceptions']      = request.exceptions
-          details['params']          = params
-          details['environment']     = request.env.merge( 'process' => $$ )
-          details['url']             = "#{request.protocol}#{request.env["HTTP_HOST"]}#{request.uri}"
+          details['exceptions']  = request.exceptions
+          details['params']      = params
+          details['params']      = self.class._filter_params(params)
+          details['environment'] = request.env.merge( 'process' => $$ )
+          details['url']         = "#{request.protocol}#{request.env["HTTP_HOST"]}#{request.uri}"
           MerbExceptions::Notification.new(details).deliver!
         rescue Exception => e
           exceptions = request.exceptions << e
           Merb.logger.fatal!("Exception Notification Failed:\n" + (exceptions).inspect)
-          File.open(Merb.root / 'log' / 'notification_errors.log', 'a') do |log|
+
+          log_dir = Merb.root / 'log'
+          unless File.directory?(log_dir)
+            require 'fileutils'
+            FileUtils.mkdir_p(log_dir)
+          end
+
+          File.open(log_dir / 'notification_errors.log', 'a') do |log|
             log.puts("Exception Notification Failed:")
             exceptions.each do |e|
               log.puts(Merb.exception(e))
